# concave_hull

A very fast 2D concave hull algorithm.

![](hull.png)

{%
   include-markdown "../README.md"
   start="<!--intro-start-->"
   end="<!--intro-end-->"
%}

<div class="text-center">
<a href="https://github.com/cubao/concave_hull" class="btn btn-primary" role="button">Code on GitHub</a>
<a href="https://pypi.org/project/concave-hull" class="btn btn-primary" role="button">Package on PyPi</a>
</div>
